Changing org.onlab.onos package to org.onosproject

Change-Id: Ic81421faa27acdcff045add47d9e0a715cd4f575
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ArraysAsListSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ArraysAsListSerializer.java
index fe54804..99c3531 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ArraysAsListSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ArraysAsListSerializer.java
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.util.ArrayList;
 import java.util.List;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ConnectPointSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ConnectPointSerializer.java
index 3cb243e..f1027d5 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ConnectPointSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ConnectPointSerializer.java
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.ConnectPoint;
-import org.onlab.onos.net.ElementId;
-import org.onlab.onos.net.PortNumber;
+import org.onosproject.net.ConnectPoint;
+import org.onosproject.net.ElementId;
+import org.onosproject.net.PortNumber;
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
 import com.esotericsoftware.kryo.io.Input;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DecodeTo.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DecodeTo.java
index a8b0379..329ef28 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DecodeTo.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DecodeTo.java
@@ -1,4 +1,4 @@
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 
@@ -21,4 +21,4 @@
     public T apply(byte[] input) {
         return serializer.decode(input);
     }
-}
\ No newline at end of file
+}
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultLinkSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultLinkSerializer.java
index dd02834..6cc9066 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultLinkSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultLinkSerializer.java
@@ -13,17 +13,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
 import com.esotericsoftware.kryo.io.Input;
 import com.esotericsoftware.kryo.io.Output;
-import org.onlab.onos.net.ConnectPoint;
-import org.onlab.onos.net.DefaultLink;
-import org.onlab.onos.net.Link.State;
-import org.onlab.onos.net.Link.Type;
-import org.onlab.onos.net.provider.ProviderId;
+import org.onosproject.net.ConnectPoint;
+import org.onosproject.net.DefaultLink;
+import org.onosproject.net.Link.State;
+import org.onosproject.net.Link.Type;
+import org.onosproject.net.provider.ProviderId;
 
 /**
  * Kryo Serializer for {@link DefaultLink}.
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultOutboundPacketSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultOutboundPacketSerializer.java
index 3dca437..9d12e45 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultOutboundPacketSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultOutboundPacketSerializer.java
@@ -13,13 +13,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.nio.ByteBuffer;
 
-import org.onlab.onos.net.DeviceId;
-import org.onlab.onos.net.flow.TrafficTreatment;
-import org.onlab.onos.net.packet.DefaultOutboundPacket;
+import org.onosproject.net.DeviceId;
+import org.onosproject.net.flow.TrafficTreatment;
+import org.onosproject.net.packet.DefaultOutboundPacket;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultPortSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultPortSerializer.java
index bed02ec..5d5a463 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultPortSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultPortSerializer.java
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.DefaultPort;
-import org.onlab.onos.net.Element;
-import org.onlab.onos.net.PortNumber;
+import org.onosproject.net.DefaultPort;
+import org.onosproject.net.Element;
+import org.onosproject.net.PortNumber;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DeviceIdSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DeviceIdSerializer.java
index ee373ac..24f18f0 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DeviceIdSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DeviceIdSerializer.java
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.net.URI;
 
-import org.onlab.onos.net.DeviceId;
+import org.onosproject.net.DeviceId;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/HostLocationSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/HostLocationSerializer.java
index 3e573d4..270eb21 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/HostLocationSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/HostLocationSerializer.java
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.DeviceId;
-import org.onlab.onos.net.HostLocation;
-import org.onlab.onos.net.PortNumber;
+import org.onosproject.net.DeviceId;
+import org.onosproject.net.HostLocation;
+import org.onosproject.net.PortNumber;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableListSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableListSerializer.java
index 8c6ee38..95166c3 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableListSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableListSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableMapSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableMapSerializer.java
index 85b98a9..4d6af78 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableMapSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableMapSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.util.Collections;
 import java.util.HashMap;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableSetSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableSetSerializer.java
index bcba7df..cb9b054 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableSetSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ImmutableSetSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.util.ArrayList;
 import java.util.List;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4AddressSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4AddressSerializer.java
index 1fee80f..0d545d4 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4AddressSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4AddressSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.Ip4Address;
 import com.esotericsoftware.kryo.Kryo;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4PrefixSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4PrefixSerializer.java
index 577d20b..695e1f7 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4PrefixSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip4PrefixSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.Ip4Prefix;
 
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6AddressSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6AddressSerializer.java
index 83c6a56..5e0e3f2 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6AddressSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6AddressSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.Ip6Address;
 import com.esotericsoftware.kryo.Kryo;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6PrefixSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6PrefixSerializer.java
index 8ecd13a..282683b 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6PrefixSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/Ip6PrefixSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.Ip6Prefix;
 
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpAddressSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpAddressSerializer.java
index 858d455..cb85fec 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpAddressSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpAddressSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.IpAddress;
 import com.esotericsoftware.kryo.Kryo;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpPrefixSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpPrefixSerializer.java
index 16bd0f4..cf0a20b 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpPrefixSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/IpPrefixSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.IpAddress;
 import org.onlab.packet.IpPrefix;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
index 231bd7f..87cd307 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoNamespaces.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.net.URI;
 import java.time.Duration;
@@ -24,95 +24,95 @@
 import java.util.HashSet;
 import java.util.LinkedList;
 
-import org.onlab.onos.cluster.ControllerNode;
-import org.onlab.onos.cluster.DefaultControllerNode;
-import org.onlab.onos.cluster.Leadership;
-import org.onlab.onos.cluster.LeadershipEvent;
-import org.onlab.onos.cluster.NodeId;
-import org.onlab.onos.cluster.RoleInfo;
-import org.onlab.onos.core.DefaultApplicationId;
-import org.onlab.onos.core.DefaultGroupId;
-import org.onlab.onos.mastership.MastershipTerm;
-import org.onlab.onos.net.ConnectPoint;
-import org.onlab.onos.net.DefaultAnnotations;
-import org.onlab.onos.net.DefaultDevice;
-import org.onlab.onos.net.DefaultEdgeLink;
-import org.onlab.onos.net.DefaultLink;
-import org.onlab.onos.net.DefaultPath;
-import org.onlab.onos.net.DefaultPort;
-import org.onlab.onos.net.Device;
-import org.onlab.onos.net.DeviceId;
-import org.onlab.onos.net.Element;
-import org.onlab.onos.net.HostId;
-import org.onlab.onos.net.HostLocation;
-import org.onlab.onos.net.Link;
-import org.onlab.onos.net.LinkKey;
-import org.onlab.onos.net.Port;
-import org.onlab.onos.net.PortNumber;
-import org.onlab.onos.net.device.DefaultDeviceDescription;
-import org.onlab.onos.net.device.DefaultPortDescription;
-import org.onlab.onos.net.flow.CompletedBatchOperation;
-import org.onlab.onos.net.flow.DefaultFlowEntry;
-import org.onlab.onos.net.flow.DefaultFlowRule;
-import org.onlab.onos.net.flow.DefaultTrafficSelector;
-import org.onlab.onos.net.flow.DefaultTrafficTreatment;
-import org.onlab.onos.net.flow.FlowEntry;
-import org.onlab.onos.net.flow.FlowId;
-import org.onlab.onos.net.flow.FlowRuleBatchEntry;
-import org.onlab.onos.net.flow.FlowRuleBatchOperation;
-import org.onlab.onos.net.flow.StoredFlowEntry;
-import org.onlab.onos.net.flow.criteria.Criteria;
-import org.onlab.onos.net.flow.criteria.Criterion;
-import org.onlab.onos.net.flow.instructions.Instructions;
-import org.onlab.onos.net.flow.instructions.L0ModificationInstruction;
-import org.onlab.onos.net.flow.instructions.L2ModificationInstruction;
-import org.onlab.onos.net.flow.instructions.L3ModificationInstruction;
-import org.onlab.onos.net.host.DefaultHostDescription;
-import org.onlab.onos.net.host.HostDescription;
-import org.onlab.onos.net.intent.ConnectivityIntent;
-import org.onlab.onos.net.intent.HostToHostIntent;
-import org.onlab.onos.net.intent.Intent;
-import org.onlab.onos.net.intent.IntentId;
-import org.onlab.onos.net.intent.IntentOperation;
-import org.onlab.onos.net.intent.IntentOperations;
-import org.onlab.onos.net.intent.IntentState;
-import org.onlab.onos.net.intent.LinkCollectionIntent;
-import org.onlab.onos.net.intent.MultiPointToSinglePointIntent;
-import org.onlab.onos.net.intent.OpticalConnectivityIntent;
-import org.onlab.onos.net.intent.OpticalPathIntent;
-import org.onlab.onos.net.intent.PathIntent;
-import org.onlab.onos.net.intent.PointToPointIntent;
-import org.onlab.onos.net.intent.constraint.AnnotationConstraint;
-import org.onlab.onos.net.intent.SinglePointToMultiPointIntent;
-import org.onlab.onos.net.intent.constraint.BandwidthConstraint;
-import org.onlab.onos.net.intent.constraint.BooleanConstraint;
-import org.onlab.onos.net.intent.constraint.LambdaConstraint;
-import org.onlab.onos.net.intent.constraint.LatencyConstraint;
-import org.onlab.onos.net.intent.constraint.LinkTypeConstraint;
-import org.onlab.onos.net.intent.constraint.ObstacleConstraint;
-import org.onlab.onos.net.intent.constraint.WaypointConstraint;
-import org.onlab.onos.net.link.DefaultLinkDescription;
-import org.onlab.onos.net.packet.DefaultOutboundPacket;
-import org.onlab.onos.net.provider.ProviderId;
-import org.onlab.onos.net.resource.Bandwidth;
-import org.onlab.onos.net.resource.BandwidthResourceAllocation;
-import org.onlab.onos.net.resource.BandwidthResourceRequest;
-import org.onlab.onos.net.resource.DefaultLinkResourceAllocations;
-import org.onlab.onos.net.resource.DefaultLinkResourceRequest;
-import org.onlab.onos.net.resource.Lambda;
-import org.onlab.onos.net.resource.LambdaResourceAllocation;
-import org.onlab.onos.net.resource.LambdaResourceRequest;
-import org.onlab.onos.net.resource.LinkResourceRequest;
-import org.onlab.onos.store.Timestamp;
-import org.onlab.onos.store.service.BatchReadRequest;
-import org.onlab.onos.store.service.BatchWriteRequest;
-import org.onlab.onos.store.service.ReadRequest;
-import org.onlab.onos.store.service.ReadResult;
-import org.onlab.onos.store.service.ReadStatus;
-import org.onlab.onos.store.service.VersionedValue;
-import org.onlab.onos.store.service.WriteRequest;
-import org.onlab.onos.store.service.WriteResult;
-import org.onlab.onos.store.service.WriteStatus;
+import org.onosproject.cluster.ControllerNode;
+import org.onosproject.cluster.DefaultControllerNode;
+import org.onosproject.cluster.Leadership;
+import org.onosproject.cluster.LeadershipEvent;
+import org.onosproject.cluster.NodeId;
+import org.onosproject.cluster.RoleInfo;
+import org.onosproject.core.DefaultApplicationId;
+import org.onosproject.core.DefaultGroupId;
+import org.onosproject.mastership.MastershipTerm;
+import org.onosproject.net.ConnectPoint;
+import org.onosproject.net.DefaultAnnotations;
+import org.onosproject.net.DefaultDevice;
+import org.onosproject.net.DefaultEdgeLink;
+import org.onosproject.net.DefaultLink;
+import org.onosproject.net.DefaultPath;
+import org.onosproject.net.DefaultPort;
+import org.onosproject.net.Device;
+import org.onosproject.net.DeviceId;
+import org.onosproject.net.Element;
+import org.onosproject.net.HostId;
+import org.onosproject.net.HostLocation;
+import org.onosproject.net.Link;
+import org.onosproject.net.LinkKey;
+import org.onosproject.net.Port;
+import org.onosproject.net.PortNumber;
+import org.onosproject.net.device.DefaultDeviceDescription;
+import org.onosproject.net.device.DefaultPortDescription;
+import org.onosproject.net.flow.CompletedBatchOperation;
+import org.onosproject.net.flow.DefaultFlowEntry;
+import org.onosproject.net.flow.DefaultFlowRule;
+import org.onosproject.net.flow.DefaultTrafficSelector;
+import org.onosproject.net.flow.DefaultTrafficTreatment;
+import org.onosproject.net.flow.FlowEntry;
+import org.onosproject.net.flow.FlowId;
+import org.onosproject.net.flow.FlowRuleBatchEntry;
+import org.onosproject.net.flow.FlowRuleBatchOperation;
+import org.onosproject.net.flow.StoredFlowEntry;
+import org.onosproject.net.flow.criteria.Criteria;
+import org.onosproject.net.flow.criteria.Criterion;
+import org.onosproject.net.flow.instructions.Instructions;
+import org.onosproject.net.flow.instructions.L0ModificationInstruction;
+import org.onosproject.net.flow.instructions.L2ModificationInstruction;
+import org.onosproject.net.flow.instructions.L3ModificationInstruction;
+import org.onosproject.net.host.DefaultHostDescription;
+import org.onosproject.net.host.HostDescription;
+import org.onosproject.net.intent.ConnectivityIntent;
+import org.onosproject.net.intent.HostToHostIntent;
+import org.onosproject.net.intent.Intent;
+import org.onosproject.net.intent.IntentId;
+import org.onosproject.net.intent.IntentOperation;
+import org.onosproject.net.intent.IntentOperations;
+import org.onosproject.net.intent.IntentState;
+import org.onosproject.net.intent.LinkCollectionIntent;
+import org.onosproject.net.intent.MultiPointToSinglePointIntent;
+import org.onosproject.net.intent.OpticalConnectivityIntent;
+import org.onosproject.net.intent.OpticalPathIntent;
+import org.onosproject.net.intent.PathIntent;
+import org.onosproject.net.intent.PointToPointIntent;
+import org.onosproject.net.intent.constraint.AnnotationConstraint;
+import org.onosproject.net.intent.SinglePointToMultiPointIntent;
+import org.onosproject.net.intent.constraint.BandwidthConstraint;
+import org.onosproject.net.intent.constraint.BooleanConstraint;
+import org.onosproject.net.intent.constraint.LambdaConstraint;
+import org.onosproject.net.intent.constraint.LatencyConstraint;
+import org.onosproject.net.intent.constraint.LinkTypeConstraint;
+import org.onosproject.net.intent.constraint.ObstacleConstraint;
+import org.onosproject.net.intent.constraint.WaypointConstraint;
+import org.onosproject.net.link.DefaultLinkDescription;
+import org.onosproject.net.packet.DefaultOutboundPacket;
+import org.onosproject.net.provider.ProviderId;
+import org.onosproject.net.resource.Bandwidth;
+import org.onosproject.net.resource.BandwidthResourceAllocation;
+import org.onosproject.net.resource.BandwidthResourceRequest;
+import org.onosproject.net.resource.DefaultLinkResourceAllocations;
+import org.onosproject.net.resource.DefaultLinkResourceRequest;
+import org.onosproject.net.resource.Lambda;
+import org.onosproject.net.resource.LambdaResourceAllocation;
+import org.onosproject.net.resource.LambdaResourceRequest;
+import org.onosproject.net.resource.LinkResourceRequest;
+import org.onosproject.store.Timestamp;
+import org.onosproject.store.service.BatchReadRequest;
+import org.onosproject.store.service.BatchWriteRequest;
+import org.onosproject.store.service.ReadRequest;
+import org.onosproject.store.service.ReadResult;
+import org.onosproject.store.service.ReadStatus;
+import org.onosproject.store.service.VersionedValue;
+import org.onosproject.store.service.WriteRequest;
+import org.onosproject.store.service.WriteResult;
+import org.onosproject.store.service.WriteStatus;
 import org.onlab.packet.ChassisId;
 import org.onlab.packet.IpAddress;
 import org.onlab.packet.Ip4Address;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoSerializer.java
index 4554f8c..dbad6d0 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/KryoSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.io.InputStream;
 import java.io.OutputStream;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/LinkKeySerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/LinkKeySerializer.java
index 7de9f3a..4bef336 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/LinkKeySerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/LinkKeySerializer.java
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.ConnectPoint;
-import org.onlab.onos.net.LinkKey;
+import org.onosproject.net.ConnectPoint;
+import org.onosproject.net.LinkKey;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/MacAddressSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/MacAddressSerializer.java
index 8e4467e..881e0ec 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/MacAddressSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/MacAddressSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import org.onlab.packet.MacAddress;
 
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/PortNumberSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/PortNumberSerializer.java
index 4dbaae4..8c104fb 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/PortNumberSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/PortNumberSerializer.java
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.PortNumber;
+import org.onosproject.net.PortNumber;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ProviderIdSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ProviderIdSerializer.java
index 26dada4..7f9b6ff 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/ProviderIdSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/ProviderIdSerializer.java
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.net.provider.ProviderId;
+import org.onosproject.net.provider.ProviderId;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/StoreSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/StoreSerializer.java
index a5a95ac..1d4dd03 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/StoreSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/StoreSerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.io.InputStream;
 import java.io.OutputStream;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/URISerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/URISerializer.java
index 895f0ac..4396966 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/URISerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/URISerializer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import java.net.URI;
 
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/package-info.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/package-info.java
index c798498..9471b43 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/package-info.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/package-info.java
@@ -17,4 +17,4 @@
 /**
  * Various Kryo serializers for use in distributed stores.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultApplicationIdSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultApplicationIdSerializer.java
index 3bf0f1e..0b1ad95 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultApplicationIdSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/DefaultApplicationIdSerializer.java
@@ -13,21 +13,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
 import com.esotericsoftware.kryo.io.Input;
 import com.esotericsoftware.kryo.io.Output;
-import org.onlab.onos.core.DefaultApplicationId;
+import org.onosproject.core.DefaultApplicationId;
 
 /**
  * Kryo Serializer for {@link org.onlab.onos.core.DefaultApplicationId}.
  */
 public final class DefaultApplicationIdSerializer extends Serializer<DefaultApplicationId> {
 
     /**
      * Creates {@link org.onlab.onos.core.DefaultApplicationId} serializer instance.
      */
     public DefaultApplicationIdSerializer() {
         // non-null, immutable
@@ -13,21 +13,21 @@
 
 /**
- * Kryo Serializer for {@link org.onlab.onos.core.DefaultApplicationId}.
+ * Kryo Serializer for {@link org.onosproject.core.DefaultApplicationId}.
  */
 public final class DefaultApplicationIdSerializer extends Serializer<DefaultApplicationId> {
@@ -13,21 +13,21 @@
 
     /**
-     * Creates {@link org.onlab.onos.core.DefaultApplicationId} serializer instance.
+     * Creates {@link org.onosproject.core.DefaultApplicationId} serializer instance.
      */
     public DefaultApplicationIdSerializer() {
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/MastershipTermSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/MastershipTermSerializer.java
index 768fb85..f30979a 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/MastershipTermSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/MastershipTermSerializer.java
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
-import org.onlab.onos.cluster.NodeId;
-import org.onlab.onos.mastership.MastershipTerm;
+import org.onosproject.cluster.NodeId;
+import org.onosproject.mastership.MastershipTerm;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
@@ -24,7 +24,7 @@
 import com.esotericsoftware.kryo.io.Output;
 
 /**
  * Kryo Serializer for {@link org.onlab.onos.mastership.MastershipTerm}.
  */
 public class MastershipTermSerializer extends Serializer<MastershipTerm> {
 
@@ -24,7 +24,7 @@
 
 /**
- * Kryo Serializer for {@link org.onlab.onos.mastership.MastershipTerm}.
+ * Kryo Serializer for {@link org.onosproject.mastership.MastershipTerm}.
  */
 public class MastershipTermSerializer extends Serializer<MastershipTerm> {
diff --git a/core/store/serializers/src/main/java/org/onosproject/store/serializers/NodeIdSerializer.java b/core/store/serializers/src/main/java/org/onosproject/store/serializers/NodeIdSerializer.java
index 1f4dc7b..da8939b 100644
--- a/core/store/serializers/src/main/java/org/onosproject/store/serializers/NodeIdSerializer.java
+++ b/core/store/serializers/src/main/java/org/onosproject/store/serializers/NodeIdSerializer.java
@@ -13,17 +13,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.store.serializers;
+package org.onosproject.store.serializers;
 
 import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.Serializer;
 import com.esotericsoftware.kryo.io.Input;
 import com.esotericsoftware.kryo.io.Output;
 
-import org.onlab.onos.cluster.NodeId;
+import org.onosproject.cluster.NodeId;
 
 /**
  * Kryo Serializer for {@link org.onlab.onos.cluster.NodeId}.
  */
 public final class NodeIdSerializer extends Serializer<NodeId> {
 
@@ -13,17 +13,17 @@
 
 /**
- * Kryo Serializer for {@link org.onlab.onos.cluster.NodeId}.
+ * Kryo Serializer for {@link org.onosproject.cluster.NodeId}.
  */
 public final class NodeIdSerializer extends Serializer<NodeId> {